#ifndef LIBFLYADMINASTRALICENSE_ASTRALICENSE_H
#define LIBFLYADMINASTRALICENSE_ASTRALICENSE_H

#include <flyadminastralicense/global.h>

namespace FlyAdmin {

//!
//! \brief The AstraLicense class to operate license for astra linux.
//!
class LIBFLYADMINASTRALICENSE_EXPORT AstraLicense
{
public:
    //!
    //! \brief The License enum = astra linux license type.
    //!
    enum License {
        None = 0,
        Orel,
        Voronezh,
        Smolensk
    };

    AstraLicense();
    explicit AstraLicense(License license);
    ~AstraLicense();

    AstraLicense(const AstraLicense &other);
    AstraLicense(AstraLicense &&other) noexcept;

    //!
    //! \brief Get current license type.
    //! \return license type.
    //!
    License license() const;

    //!
    //! \brief Set current license type.
    //! \param license - license type.
    //!
    void setLicense(License license);

    //!
    //! \brief Read license type from string.
    //! \param licenseText - license name.
    //! \return license type.
    //!
    static License fromString(const QString &licenseText);

    //!
    //! \brief Convert license type to string.
    //! \param license - license type.
    //! \return license name.
    //!
    static QString toString(License license);

    //!
    //! \brief Convert license type to string.
    //! \return license name.
    //!
    QString toString() const;

    //!
    //! \brief Convert license type to string for user.
    //! \param license - license type.
    //! \return user license name.
    //!
    static QString toUserString(License license);

    //!
    //! \brief Convert license type to level string for user.
    //! \param license - license type.
    //! \return user license level name.
    //!
    static QString toLevelString(License license);

    //!
    //! \brief Convert license type to string for user.
    //! \return user license name.
    //!
    QString toUserString() const;

    //!
    //! \brief Convert license type to level string for user.
    //! \return user license level name.
    //!
    QString toLevelString() const;

    //!
    //! \brief Returns the defaukt key for storing the license in the settings
    //! \return String containing default key
    //!
    static QString defaultEntryKey();

    AstraLicense &operator=(const AstraLicense &other);
    AstraLicense &operator=(AstraLicense &&other);

    bool operator==(const AstraLicense &other) const;
    bool operator!=(const AstraLicense &other) const;

    AstraLicense &operator=(License other);

    bool operator==(License license) const noexcept;
    bool operator!=(License license) const noexcept;

private:
    License m_license;
};

} // namespace FlyAdmin

#endif // LIBFLYADMINASTRALICENSE_ASTRALICENSE_H
